@@ -84,10 +84,10 @@ class BlobReader:
 
 class IdGenerator:
     @staticmethod
-    def generate_request_id(data, guid=None):
+    def generate_request_id(data, worker_name, guid=None):
         if not guid:
             guid = IdGenerator.generate_id()
-        data_to_hash = data + str(uuid.uuid4())
+        data_to_hash = data + worker_name
         request_hash = str(hashlib.md5(data_to_hash.encode()).hexdigest())
         request_id = "%s_%s" % (guid, request_hash)
         return guid, request_hash, request_id
@@ -166,7 +166,7 @@ class MetadataRepository:
     def insert_raw_metadata(self, data: List[str], params) -> str:
         entity = {"Data": data, "Params": params}
         serialized_body = json.dumps(entity)
-        guid, request_hash, request_id = IdGenerator.generate_request_id(serialized_body)
+        guid, request_hash, request_id = IdGenerator.generate_request_id(serialized_body, worker_name=self.metadata_table_name)
         metadata = {"PartitionKey": guid, "RowKey": request_hash, "Request": serialized_body }
         self.table_client.insert_entity(self.metadata_table_name, metadata)
         return request_id
@@ -178,14 +178,14 @@ class MetadataRepository:
         for blobs_chunk in chunks(blob_names, 99):
             batch = TableBatch()
             for blob_name in blobs_chunk:
-                guid, request_hash, request_id = IdGenerator.generate_request_id(blob_name, guid)
+                guid, request_hash, request_id = IdGenerator.generate_request_id(blob_name, worker_name=self.metadata_table_name, guid=guid)
                 batch.insert_or_replace_entity({"PartitionKey": guid, "RowKey": request_hash, "BlobName": blob_name, "Params": params})
                 request_ids.append(request_id)
             self.table_client.commit_batch(self.metadata_table_name, batch)
         return request_ids
 
     def insert_blob_metadata(self, blob_name, params=None, guid=None) -> str:
-        guid, request_hash, request_id = IdGenerator.generate_request_id(blob_name, guid)
+        guid, request_hash, request_id = IdGenerator.generate_request_id(blob_name, worker_name=self.metadata_table_name, guid=guid)
         metadata_entity = {"PartitionKey": guid, "RowKey": request_hash, "BlobName": blob_name}
         if params:
             metadata_entity['Params'] = json.dumps(params)
